@@ -15,11 +15,14 @@ test_that("Travis successfully uses API key", {
 
 test_that("Retrying image processing can be successful", {
     skip_on_cran()
-    ## this one should fail
-    expect_error(suppressWarnings(mathpix(system.file("extdata", "eq_no_05_screencapfixes.jpg", package = "mathpix"), insert = FALSE, retry = FALSE)))
+    ## this one no longer fails
+    expect_equal(gsub(" ", "", suppressWarnings(mathpix(system.file("extdata", "eq_no_05_screencapfixes.jpg", package = "mathpix"), insert = FALSE, retry = FALSE))),
+                 gsub(" ", "", "$$
+ p _ { i } ( \\theta ) = c _ { i } + \\frac { 1- c _ { i } } { 1+ e ^ { - a _ { i } ( \\theta - b _ { i } ) } }
+$$"))
     ## this one should work
-    expect_equal(suppressWarnings(mathpix(system.file("extdata", "eq_no_05_screencapfixes.jpg", package = "mathpix"), insert = FALSE, retry = TRUE)),
-                 "$$\n p _ { i } ( \\theta ) = c _ { i } + \\frac { 1- c _ { i } } { 1+ e ^ { - a _ { i } \\theta - b _ { i } ) } } \n$$")
+    expect_equal(gsub(" ", "", suppressWarnings(mathpix(system.file("extdata", "eq_no_05_screencapfixes.jpg", package = "mathpix"), insert = FALSE, retry = TRUE))),
+                 gsub(" ", "", "$$\n p _ { i } ( \\theta ) = c _ { i } + \\frac { 1- c _ { i } } { 1+ e ^ { - a _ { i } (\\theta - b _ { i } ) } } \n$$"))
 })
 
 context("File processing")
